@@ -129,7 +129,7 @@ def download_file(identifier, filename, **kwargs):
 # get_tasks()
 #_________________________________________________________________________________________
 def get_tasks(**kwargs): 
-    catalog = service.Catalog(**kwargs)
+    catalog = service.Catalog(kwargs.get('params'))
     task_type = kwargs.get('task_type')
     if task_type:
         return eval('catalog.{0}_rows'.format(task_type.lower()))
